pub struct HashedHubPseudonymPackage {
pub hashed_hub_pseudonym: CurvePoint,
pub pp_issued_at: NumericDate,
pub hub_nonce: EnterNonce,
}Expand description
Returned (in sealed form) by phc::user::HhppEP, needed for hub::EnterCompleteEP.
Fields
hashed_hub_pseudonym: CurvePointThe hashed hub pseudonym, hashed to a point on curve25519 so we can decide to add an additional layer of ElGamal encryption later on.
pp_issued_at: NumericDateWhen the original pseudonym was issued
hub_nonce: EnterNonceNonce, from hub::EnterStartEP